==> imce_private-2.0.0.tar.gz: imce_private/js/plugins/ckeditor/imce_private.ckeditor.js <==
/**
 * @file
 * IMCE Private module Gulpfile.
 */

(function ($, Drupal, CKEDITOR) {
  'use strict';

  /**
   * @file
   * Defines ImcePrivate plugin for CKEditor.
   */

  CKEDITOR.plugins.add('imceprivate', {
    // Define commands and buttons.
    init: function (editor) {
      // Image.
      editor.addCommand('imceimageprivate', {
        exec: CKEDITOR.imceprivate.imageDialogPrivate,
      });
      editor.ui.addButton('ImceImagePrivate', {
        label: CKEDITOR.imceprivate.imageLabel('private'),
        command: 'imceimageprivate',
        icon: editor.config.ImceImageIconPrivate,
      });
      editor.addCommand('imceimagepublic', {
        exec: CKEDITOR.imceprivate.imageDialogPublic,
      });
      editor.ui.addButton('ImceImagePublic', {
        label: CKEDITOR.imceprivate.imageLabel('public'),
        command: 'imceimagepublic',
        icon: editor.config.ImceImageIconPublic,
      });
      // Link.
      editor.addCommand('imcelinkprivate', {
        exec: CKEDITOR.imceprivate.linkDialogPrivate,
      });
      editor.ui.addButton('ImceLinkPrivate', {
        label: CKEDITOR.imceprivate.linkLabel('private'),
        command: 'imcelinkprivate',
        icon: editor.config.ImceLinkIconPrivate,
      });
      editor.addCommand('imcelinkpublic', {
        exec: CKEDITOR.imceprivate.linkDialogPublic,
      });
      editor.ui.addButton('ImceLinkPublic', {
        label: CKEDITOR.imceprivate.linkLabel('public'),
        command: 'imcelinkpublic',
        icon: editor.config.ImceLinkIconPublic,
      });
    }
  });

  /**
   * Global container for helper methods.
   */
  CKEDITOR.imceprivate = CKEDITOR.imceprivate || {

    /**
     * Returns image button label.
     */
    imageLabel: function (scheme) {
      return Drupal.t('Insert ' + scheme + ' images using Imce File Manager');
    },

    /**
     * Opens Imce for inserting private images into CKEditor.
     */
    imageDialogPrivate: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'private');
    },

    /**
     * Opens Imce for inserting public images into CKEditor.
     */
    imageDialogPublic: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'public');
    },

    /**
     * Returns link button label.
     */
    linkLabel: function (scheme) {
      return Drupal.t('Insert ' + scheme + ' file links using Imce File Manager');
    },

    /**
     * Opens Imce for inserting private links into CKEditor.
     */
    linkDialogPrivate: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'private');
    },

    /**
     * Opens Imce for inserting public links into CKEditor.
     */
    linkDialogPublic: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'public');
    },

    /**
     * Opens Imce for inserting images or links into CKEditor.
     */
    openDialog: function (editor, type, scheme) {
      const width = Math.min(1000, parseInt(screen.availWidth * 0.8));
      const height = Math.min(800, parseInt(screen.availHeight * 0.8));
      const url = CKEDITOR.imceprivate.url('sendto=CKEDITOR.imce.sendto&type=' + type + '&ck_id=' + encodeURIComponent(editor.name), scheme);
      editor.popup(url, width, height);
    },

    /**
     * Returns Imce url.
     */
    url: function (query, scheme) {
      let url = Drupal.url('imce');
      if (scheme) {
        url += '/' + scheme;
      }
      if (query) {
        url += (url.indexOf('?') === -1 ? '?' : '&') + query;
      }
      return url;
    },

  };

})(jQuery, Drupal, CKEDITOR);

==> imce_private-2.0.2.tar.gz: imce_private/js/plugins/ckeditor/imce_private.ckeditor.js <==
/**
 * @file
 * IMCE Private module JS.
 */

/* global CKEDITOR */

(($, Drupal, CKEDITOR) => {
  /**
   * @file
   * Defines ImcePrivate plugin for CKEditor.
   */

  CKEDITOR.plugins.add('imceprivate', {
    // Define commands and buttons.
    init(editor) {
      // Image.
      editor.addCommand('imceimageprivate', {
        exec: CKEDITOR.imceprivate.imageDialogPrivate,
      });
      editor.ui.addButton('ImceImagePrivate', {
        label: CKEDITOR.imceprivate.imageLabel('private'),
        command: 'imceimageprivate',
        icon: editor.config.ImceImageIconPrivate,
      });
      editor.addCommand('imceimagepublic', {
        exec: CKEDITOR.imceprivate.imageDialogPublic,
      });
      editor.ui.addButton('ImceImagePublic', {
        label: CKEDITOR.imceprivate.imageLabel('public'),
        command: 'imceimagepublic',
        icon: editor.config.ImceImageIconPublic,
      });
      // Link.
      editor.addCommand('imcelinkprivate', {
        exec: CKEDITOR.imceprivate.linkDialogPrivate,
      });
      editor.ui.addButton('ImceLinkPrivate', {
        label: CKEDITOR.imceprivate.linkLabel('private'),
        command: 'imcelinkprivate',
        icon: editor.config.ImceLinkIconPrivate,
      });
      editor.addCommand('imcelinkpublic', {
        exec: CKEDITOR.imceprivate.linkDialogPublic,
      });
      editor.ui.addButton('ImceLinkPublic', {
        label: CKEDITOR.imceprivate.linkLabel('public'),
        command: 'imcelinkpublic',
        icon: editor.config.ImceLinkIconPublic,
      });
    },
  });

  /**
   * Global container for helper methods.
   */
  CKEDITOR.imceprivate = CKEDITOR.imceprivate || {
    /**
     * Returns image button label.
     *
     * @param {string} scheme - Scheme.
     * @return {string} Returns label.
     */
    imageLabel(scheme) {
      return Drupal.t(`Insert ${scheme} images using Imce File Manager`);
    },

    /**
     * Opens Imce for inserting private images into CKEditor.
     *
     * @param {string} editor - Editor.
     * @return {string} Returns dialog.
     */
    imageDialogPrivate(editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'private');
    },

    /**
     * Opens Imce for inserting public images into CKEditor.
     *
     * @param {string} editor - Editor.
     * @return {string} Returns dialog.
     */
    imageDialogPublic(editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'public');
    },

    /**
     * Returns link button label.
     *
     * @param {string} scheme - Scheme.
     * @return {string} Returns label.
     */
    linkLabel(scheme) {
      return Drupal.t(`Insert ${scheme} file links using Imce File Manager`);
    },

    /**
     * Opens Imce for inserting private links into CKEditor.
     *
     * @param {string} editor - Editor.
     * @return {string} Returns dialog.
     */
    linkDialogPrivate(editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'private');
    },

    /**
     * Opens Imce for inserting public links into CKEditor.
     *
     * @param {string} editor - Editor.
     * @return {string} Returns dialog.
     */
    linkDialogPublic(editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'public');
    },

    /**
     * Opens Imce for inserting images or links into CKEditor.
     *
     * @param {string} editor - Editor.
     * @param {string} type - Type.
     * @param {string} scheme - Scheme.
     */
    openDialog(editor, type, scheme) {
      const width = Math.min(
        1000,
        parseInt(window.screen.availWidth * 0.8, 10),
      );
      const height = Math.min(
        800,
        parseInt(window.screen.availHeight * 0.8, 10),
      );
      const editorname = encodeURIComponent(editor.name);
      const url = CKEDITOR.imceprivate.url(
        `sendto=CKEDITOR.imce.sendto&type=${type}&ck_id=${editorname}`,
        scheme,
      );
      editor.popup(url, width, height);
    },

    /**
     * Returns Imce url.
     *
     * @param {string} query - Query.
     * @param {string} scheme - Scheme.
     * @return {string} Returns Url.
     */
    url(query, scheme) {
      let url = Drupal.url('imce');
      if (scheme) {
        url += `/${scheme}`;
      }
      if (query) {
        url += (url.indexOf('?') === -1 ? '?' : '&') + query;
      }
      return url;
    },
  };
})(jQuery, Drupal, CKEDITOR);
